summaryrefslogtreecommitdiffstats
path: root/src/core/manager.h
diff options
context:
space:
mode:
authorDaan De Meyer <daan.j.demeyer@gmail.com>2023-03-26 20:07:36 +0200
committerDaan De Meyer <daan.j.demeyer@gmail.com>2023-03-27 14:05:30 +0200
commite76506b74816174cf9ec26262c7c4669a6d5172d (patch)
treeabe1a4213fba681dfed13856b79abc4c8c5d4d14 /src/core/manager.h
parentmkosi: Narrow glob used to install python packages (diff)
downloadsystemd-e76506b74816174cf9ec26262c7c4669a6d5172d.tar.xz
systemd-e76506b74816174cf9ec26262c7c4669a6d5172d.zip
execute: Rename ExecRuntime to ExecSharedRuntime
Preparation for next commit
Diffstat (limited to 'src/core/manager.h')
-rw-r--r--src/core/manager.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/manager.h b/src/core/manager.h
index 25fcd275d4..fc95b75120 100644
--- a/src/core/manager.h
+++ b/src/core/manager.h
@@ -429,8 +429,8 @@ struct Manager {
Hashmap *uid_refs;
Hashmap *gid_refs;
- /* ExecRuntime, indexed by their owner unit id */
- Hashmap *exec_runtime_by_id;
+ /* ExecSharedRuntime, indexed by their owner unit id */
+ Hashmap *exec_shared_runtime_by_id;
/* When the user hits C-A-D more than 7 times per 2s, do something immediately... */
RateLimit ctrl_alt_del_ratelimit;